Skip to contents

Function to retrieve a full metric name based on the short name using the LakeCat API.

Usage

lc_fullname(metric = NULL)

Arguments

metric

Short metric name Syntax: metric=value1 Values: metric

Value

A lookup of the full name for a given LakeCat metric

Author

Marc Weber

Examples

fullname <- lc_fullname(metric='clay')
#> Warning: URL 'https://api.epa.gov/StreamCat/lakes/datadictionary': Timeout of 60 seconds was reached
#> An error occurred during req_perform(); the service may be down or function parameters may be mis-specified: cannot read from connection