Learn R Programming

StreamCatTools (version 0.10.0)

lc_get_metric_names: Get LakeCat Metric Names

Description

Function to filter LakeCat metrics metrics by category, area of interest, dataset or year. Use `lc_get_params(categories)` or `lc_get_params(datasets)` to see all the valid category or dataset options

Usage

lc_get_metric_names(category = NULL, aoi = NULL, year = NULL, dataset = NULL)

Value

A dataframe of merics and description that match filter criteria

Arguments

category

Filter LakeCat metrics based on the metric category

aoi

Filter LakeCat metrics based on the area of interest

year

Filter LakeCat metrics based on a particular year or years

dataset

Filter LakeCat metrics based on the dataset name

Author

Marc Weber

Examples

Run this code
if (FALSE) {
metrics <- lc_get_metric_names(category='Natural')
metrics <- lc_get_metric_names(category = c('Anthropogenic','Natural'),
aoi=c('Cat','Ws'))}

Run the code above in your browser using DataLab