Learn R Programming

StreamCatTools (version 0.10.0)

sc_get_metric_names: Get StreamCat Metric Names

Description

Function to filter StreamCat metrics metrics by category, area of interest, dataset or year. Use `sc_get_params(categories)` or `sc_get_params(datasets)` to see all the valid category or dataset options

Usage

sc_get_metric_names(category = NULL, aoi = NULL, year = NULL, dataset = NULL)

Value

A dataframe of merics and description that match filter criteria

Arguments

category

Filter StreamCat metrics based on the metric category

aoi

Filter StreamCat metrics based on the area of interest

year

Filter StreamCat metrics based on a particular year or years

dataset

Filter StreamCat metrics based on the dataset name

Author

Marc Weber

Examples

Run this code
if (FALSE) {
metrics <- sc_get_metric_names(category='Wildfire')
metrics <- sc_get_metric_names(category = c('Deposition','Climate'),
aoi=c('Cat','Ws'))
metrics <- sc_get_metric_names(aoi='Other',
dataset=c('Canal Density','Predicted Channel Widths Depths'))

}

Run the code above in your browser using DataLab